==> php54-owncloud-8.0.3.tgz: share/owncloud/settings/l10n/zh_TW.js <==
OC.L10N.register(
    "settings",
    {
    "Security & Setup Warnings" : "安全及警告設定",
    "Cron" : "工作排程",
    "Sharing" : "分享",
    "Security" : "安全性",
    "Email Server" : "郵件伺服器",
    "Log" : "紀錄",
    "Authentication error" : "認證錯誤",
    "Your full name has been changed." : "您的全名已變更。",
    "Unable to change full name" : "無法變更全名",
    "Files decrypted successfully" : "檔案解密成功",
    "Couldn't decrypt your files, please check your owncloud.log or ask your administrator" : "無法解密您的檔案，請檢查您的 owncloud.log 或是詢問您的管理者",
    "Couldn't decrypt your files, check your password and try again" : "無法解密您的檔案，確認您的密碼並再重試一次",
    "Encryption keys deleted permanently" : "加密密鑰已永久刪除",
    "Couldn't remove app." : "無法移除應用程式",
    "Backups restored successfully" : "備份檔回復成功",
    "Language changed" : "語言已變更",
    "Invalid request" : "無效請求",
    "Admins can't remove themself from the admin group" : "管理者帳號無法從管理者群組中移除",
    "Unable to add user to group %s" : "使用者加入群組 %s 錯誤",
    "Unable to remove user from group %s" : "使用者移出群組 %s 錯誤",
    "Couldn't update app." : "無法更新應用程式",
    "Wrong password" : "密碼錯誤",
    "No user supplied" : "未提供使用者",
    "Please provide an admin recovery password, otherwise all user data will be lost" : "請提供管理者還原密碼，否則會遺失所有使用者資料",
    "Wrong admin recovery password. Please check the password and try again." : "錯誤的管理者還原密碼",
    "Back-end doesn't support password change, but the users encryption key was successfully updated." : "後端不支援變更密碼，但成功更新使用者的加密金鑰",
    "Unable to change password" : "無法修改密碼",
    "Enabled" : "已啓用",
    "Not enabled" : "無啟動",
    "Recommended" : "建議",
    "Group already exists." : "群組已存在",
    "Saved" : "已儲存",
    "test email settings" : "測試郵件設定",
    "If you received this email, the settings seem to be correct." : "假如您收到這個郵件，此設定看起來是正確的。",
    "Email sent" : "Email 已寄出",
    "You need to set your user email before being able to send test emails." : "在準備要寄出測試郵件時您需要設定您的使用者郵件。",
    "Email saved" : "Email已儲存",
    "Sending..." : "寄送中...",
    "All" : "所有",
    "Please wait...." : "請稍候...",
    "Error while disabling app" : "停用應用程式錯誤",
    "Disable" : "停用",
    "Enable" : "啟用",
    "Error while enabling app" : "啓用應用程式錯誤",
    "Updating...." : "更新中...",
    "Error while updating app" : "更新應用程式錯誤",
    "Updated" : "已更新",
    "Select a profile picture" : "選擇大頭貼",
    "Very weak password" : "非常弱的密碼",
    "Weak password" : "弱的密碼",
    "So-so password" : "普通的密碼",
    "Good password" : "好的密碼",
    "Strong password" : "很強的密碼",
    "Delete" : "刪除",
    "Decrypting files... Please wait, this can take some time." : "檔案解密中，請稍候。",
    "Groups" : "群組",
    "undo" : "復原",
    "never" : "永不",
    "add group" : "新增群組",
    "A valid username must be provided" : "必須提供一個有效的用戶名",
    "Error creating user" : "建立用戶時出現錯誤",
    "A valid password must be provided" : "一定要提供一個有效的密碼",
    "__language_name__" : "__language_name__",
    "SSL root certificates" : "SSL 根憑證",
    "Encryption" : "加密",
    "Everything (fatal issues, errors, warnings, info, debug)" : "全部(嚴重問題,錯誤,警告,資訊,除錯)",
    "Info, warnings, errors and fatal issues" : "資訊,警告,錯誤和嚴重問題",
    "Warnings, errors and fatal issues" : "警告,錯誤和嚴重問題",
    "Errors and fatal issues" : "錯誤和嚴重問題",
    "Fatal issues only" : "只有嚴重問題",
    "None" : "無",
    "Login" : "登入",
    "Plain" : "文字",
    "NT LAN Manager" : "NT LAN Manager",
    "SSL" : "SSL",
    "TLS" : "TLS",
    "Security Warning" : "安全性警告",
    "You are accessing %s via HTTP. We strongly suggest you configure your server to require using HTTPS instead." : "您正透過未加密網頁存取 %s。我們強烈建議您設定您的主機必須使用加密網頁。",
    "Setup Warning" : "設定警告",
    "Module 'fileinfo' missing" : "遺失 'fileinfo' 模組",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "未偵測到 PHP 模組 'fileinfo'。我們強烈建議啟用這個模組以取得最好的 mime-type 支援。",
    "Locale not working" : "語系無法運作",
    "System locale can not be set to a one which supports UTF-8." : "系統語系無法設定只支援 UTF-8",
    "This means that there might be problems with certain characters in file names." : "這個意思是指在檔名中使用一些字元可能會有問題",
    "Please double check the <a href='%s'>installation guides</a>." : "請參考<a href='%s'>安裝指南</a>。",
    "Last cron was executed at %s." : "最後的排程已執行於 %s。",
    "Last cron was executed at %s. This is more than an hour ago, something seems wrong." : "最後的排程已執行於 %s。現在過了好幾個小時，看起來是有錯誤。",
    "Cron was not executed yet!" : "排程沒有執行!",
    "Execute one task with each page loaded" : "當頁面載入時，執行",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "已經與 webcron 服務註冊好，將會每15分鐘呼叫 cron.php",
    "Allow apps to use the Share API" : "允許 apps 使用分享 API",
    "Allow public uploads" : "允許任何人上傳",
    "Allow users to send mail notification for shared files" : "允許使用者寄送有關分享檔案的郵件通知",
    "Allow resharing" : "允許轉貼分享",
    "Enforce HTTPS" : "強制啟用 HTTPS",
    "Forces the clients to connect to %s via an encrypted connection." : "強迫用戶端使用加密連線連接到 %s",
    "Please connect to your %s via HTTPS to enable or disable the SSL enforcement." : "請使用 HTTPS 連線到 %s 以啓用或停用強制 SSL 加密。",
    "This is used for sending out notifications." : "這是使用於寄送通知。",
    "Send mode" : "寄送模式",
    "From address" : "寄件地址",
    "Authentication method" : "驗證方式",
    "Authentication required" : "必須驗證",
    "Server address" : "伺服器位址",
    "Port" : "連接埠",
    "Credentials" : "認證",
    "SMTP Username" : "SMTP 帳號",
    "SMTP Password" : "SMTP 密碼",
    "Test email settings" : "測試郵件設定",
    "Send email" : "寄送郵件",
    "Log level" : "紀錄層級",
    "More" : "更多",
    "Less" : "更少",
    "Version" : "版本",
    "Developed by the <a href=\"http://ownCloud.org/contact\" target=\"_blank\">ownCloud community</a>, the <a href=\"https://github.com/owncloud\" target=\"_blank\">source code</a> is licensed under the <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a>." : "由 <a href=\"http://ownCloud.org/contact\" target=\"_blank\">ownCloud 社群</a>開發，<a href=\"https://github.com/owncloud\" target=\"_blank\">原始碼</a>在 <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a> 授權許可下發布。",
    "More apps" : "更多 Apps",
    "by" : "由",
    "Documentation:" : "文件:",
    "User Documentation" : "用戶說明文件",
    "Admin Documentation" : "管理者文件",
    "Cheers!" : "太棒了！",
    "Administrator Documentation" : "管理者說明文件",
    "Online Documentation" : "線上說明文件",
    "Forum" : "論壇",
    "Bugtracker" : "Bugtracker",
    "Commercial Support" : "商用支援",
    "Get the apps to sync your files" : "下載應用程式來同步您的檔案",
    "Show First Run Wizard again" : "再次顯示首次使用精靈",
    "You have used <strong>%s</strong> of the available <strong>%s</strong>" : "您已經使用了 <strong>%s</strong> ，目前可用空間為 <strong>%s</strong>",
    "Password" : "密碼",
    "Your password was changed" : "你的密碼已更改",
    "Unable to change your password" : "無法變更您的密碼",
    "Current password" : "目前密碼",
    "New password" : "新密碼",
    "Change password" : "變更密碼",
    "Full Name" : "全名",
    "Email" : "信箱",
    "Your email address" : "您的電子郵件信箱",
    "Fill in an email address to enable password recovery and receive notifications" : "填入電子郵件地址來啟用忘記密碼和接收通知的功能",
    "Profile picture" : "個人資料照片",
    "Upload new" : "上傳新的",
    "Select new from Files" : "從已上傳的檔案中選一個",
    "Remove image" : "移除圖片",
    "Either png or jpg. Ideally square but you will be able to crop it." : "可以使用 png 或 jpg 格式，最好是方形的，但是您之後也可以裁剪它",
    "Your avatar is provided by your original account." : "您的圖像是由您原來的帳號所提供的。",
    "Cancel" : "取消",
    "Choose as profile image" : "設定為大頭貼",
    "Language" : "語言",
    "Help translate" : "幫助翻譯",
    "Import Root Certificate" : "匯入根憑證",
    "The encryption app is no longer enabled, please decrypt all your files" : "加密的軟體不能長時間啟用，請解密所有您的檔案",
    "Log-in password" : "登入密碼",
    "Decrypt all Files" : "解密所有檔案",
    "Username" : "使用者名稱",
    "Create" : "建立",
    "Admin Recovery Password" : "管理者復原密碼",
    "Enter the recovery password in order to recover the users files during password change" : "為了修改密碼時能夠取回使用者資料，請輸入另一組還原用密碼",
    "Group" : "群組",
    "Default Quota" : "預設容量限制",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "請輸入空間配額(例如: \"512 MB\"或是 \"12 GB\")",
    "Unlimited" : "無限制",
    "Other" : "其他",
    "Quota" : "容量限制",
    "change full name" : "變更全名",
    "set new password" : "設定新密碼",
    "Default" : "預設"
},
"nplurals=1; plural=0;");

==> php54-owncloud-8.1.0.tgz: share/owncloud/settings/l10n/zh_TW.js <==
OC.L10N.register(
    "settings",
    {
    "Sharing" : "分享",
    "External Storage" : "外部儲存",
    "Cron" : "工作排程",
    "Log" : "紀錄",
    "Updates" : "更新",
    "Authentication error" : "認證錯誤",
    "Your full name has been changed." : "您的全名已變更。",
    "Unable to change full name" : "無法變更全名",
    "Couldn't remove app." : "無法移除應用程式",
    "Language changed" : "語言已變更",
    "Invalid request" : "無效請求",
    "Admins can't remove themself from the admin group" : "管理者帳號無法從管理者群組中移除",
    "Unable to add user to group %s" : "使用者加入群組 %s 錯誤",
    "Unable to remove user from group %s" : "使用者移出群組 %s 錯誤",
    "Couldn't update app." : "無法更新應用程式",
    "Wrong password" : "密碼錯誤",
    "No user supplied" : "未提供使用者",
    "Please provide an admin recovery password, otherwise all user data will be lost" : "請提供管理者還原密碼，否則會遺失所有使用者資料",
    "Wrong admin recovery password. Please check the password and try again." : "錯誤的管理者還原密碼",
    "Unable to change password" : "無法修改密碼",
    "Enabled" : "已啓用",
    "Not enabled" : "無啟動",
    "Group already exists." : "群組已存在",
    "Saved" : "已儲存",
    "test email settings" : "測試郵件設定",
    "Email sent" : "Email 已寄出",
    "You need to set your user email before being able to send test emails." : "在準備要寄出測試郵件時您需要設定您的使用者郵件。",
    "Email saved" : "Email已儲存",
    "Sending..." : "寄送中...",
    "All" : "所有",
    "Please wait...." : "請稍候...",
    "Error while disabling app" : "停用應用程式錯誤",
    "Disable" : "停用",
    "Enable" : "啟用",
    "Error while enabling app" : "啓用應用程式錯誤",
    "Updating...." : "更新中...",
    "Error while updating app" : "更新應用程式錯誤",
    "Updated" : "已更新",
    "Select a profile picture" : "選擇大頭貼",
    "Very weak password" : "非常弱的密碼",
    "Weak password" : "弱的密碼",
    "So-so password" : "普通的密碼",
    "Good password" : "好的密碼",
    "Strong password" : "很強的密碼",
    "Delete" : "刪除",
    "Groups" : "群組",
    "undo" : "復原",
    "never" : "永不",
    "add group" : "新增群組",
    "A valid username must be provided" : "必須提供一個有效的用戶名",
    "Error creating user" : "建立用戶時出現錯誤",
    "A valid password must be provided" : "一定要提供一個有效的密碼",
    "__language_name__" : "__language_name__",
    "SSL root certificates" : "SSL 根憑證",
    "Everything (fatal issues, errors, warnings, info, debug)" : "全部(嚴重問題,錯誤,警告,資訊,除錯)",
    "Info, warnings, errors and fatal issues" : "資訊,警告,錯誤和嚴重問題",
    "Warnings, errors and fatal issues" : "警告,錯誤和嚴重問題",
    "Errors and fatal issues" : "錯誤和嚴重問題",
    "Fatal issues only" : "只有嚴重問題",
    "None" : "無",
    "Login" : "登入",
    "Plain" : "文字",
    "NT LAN Manager" : "NT LAN Manager",
    "SSL" : "SSL",
    "TLS" : "TLS",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "未偵測到 PHP 模組 'fileinfo'。我們強烈建議啟用這個模組以取得最好的 mime-type 支援。",
    "System locale can not be set to a one which supports UTF-8." : "系統語系無法設定只支援 UTF-8",
    "This means that there might be problems with certain characters in file names." : "這個意思是指在檔名中使用一些字元可能會有問題",
    "Allow apps to use the Share API" : "允許 apps 使用分享 API",
    "Allow public uploads" : "允許任何人上傳",
    "Allow users to send mail notification for shared files" : "允許使用者寄送有關分享檔案的郵件通知",
    "days" : "天",
    "Allow resharing" : "允許轉貼分享",
    "Cron was not executed yet!" : "排程沒有執行!",
    "Execute one task with each page loaded" : "當頁面載入時，執行",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "已經與 webcron 服務註冊好，將會每15分鐘呼叫 cron.php",
    "This is used for sending out notifications." : "這是使用於寄送通知。",
    "Send mode" : "寄送模式",
    "Encryption" : "加密",
    "From address" : "寄件地址",
    "Authentication method" : "驗證方式",
    "Authentication required" : "必須驗證",
    "Server address" : "伺服器位址",
    "Port" : "連接埠",
    "Credentials" : "認證",
    "SMTP Username" : "SMTP 帳號",
    "SMTP Password" : "SMTP 密碼",
    "Test email settings" : "測試郵件設定",
    "Send email" : "寄送郵件",
    "Log level" : "紀錄層級",
    "More" : "更多",
    "Less" : "更少",
    "Version" : "版本",
    "by" : "由",
    "Documentation:" : "文件:",
    "User Documentation" : "用戶說明文件",
    "Admin Documentation" : "管理者文件",
    "Cheers!" : "太棒了！",
    "Forum" : "論壇",
    "Get the apps to sync your files" : "下載應用程式來同步您的檔案",
    "Show First Run Wizard again" : "再次顯示首次使用精靈",
    "You have used <strong>%s</strong> of the available <strong>%s</strong>" : "您已經使用了 <strong>%s</strong> ，目前可用空間為 <strong>%s</strong>",
    "Password" : "密碼",
    "Unable to change your password" : "無法變更您的密碼",
    "Current password" : "目前密碼",
    "New password" : "新密碼",
    "Change password" : "變更密碼",
    "Email" : "信箱",
    "Your email address" : "您的電子郵件信箱",
    "Fill in an email address to enable password recovery and receive notifications" : "填入電子郵件地址來啟用忘記密碼和接收通知的功能",
    "Profile picture" : "個人資料照片",
    "Upload new" : "上傳新的",
    "Select new from Files" : "從已上傳的檔案中選一個",
    "Remove image" : "移除圖片",
    "Either png or jpg. Ideally square but you will be able to crop it." : "可以使用 png 或 jpg 格式，最好是方形的，但是您之後也可以裁剪它",
    "Your avatar is provided by your original account." : "您的圖像是由您原來的帳號所提供的。",
    "Cancel" : "取消",
    "Choose as profile image" : "設定為大頭貼",
    "Language" : "語言",
    "Help translate" : "幫助翻譯",
    "Username" : "使用者名稱",
    "Create" : "建立",
    "Admin Recovery Password" : "管理者復原密碼",
    "Enter the recovery password in order to recover the users files during password change" : "為了修改密碼時能夠取回使用者資料，請輸入另一組還原用密碼",
    "Group" : "群組",
    "Default Quota" : "預設容量限制",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "請輸入空間配額(例如: \"512 MB\"或是 \"12 GB\")",
    "Unlimited" : "無限制",
    "Other" : "其他",
    "Full Name" : "全名",
    "Quota" : "容量限制",
    "change full name" : "變更全名",
    "set new password" : "設定新密碼",
    "Default" : "預設"
},
"nplurals=1; plural=0;");
